=====================
django-scaffold-tools
=====================

A reusable django-app set for a DRF django project, starting support from django 3.0.

If you want to build a Django-Rest-Framework project about your business requirements,
this project helps you do all kinds of redundant work which may be similar between
different projects.

It supports the following features:

* base_config: Deal with project/user level user-config terms.
* base_settings: Common setting wrapped up as a model with default settings you need

Quick start
-----------

```
pip install django-scaffold-tools
```

